@@ -5,7 +5,7 @@
 ;; Author: Pranshu Sharma <pranshu@bauherren.ovh>
 ;; URL: https://codeberg.org/pranshu/haskell-ts-mode
 ;; Package-Requires: ((emacs "29.3"))
-;; Version: 1.3.4
+;; Version: 1.3.5
 ;; Keywords: languages, haskell
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -143,9 +143,12 @@ when `haskell-ts-prettify-words' is non-nil.")
    :override t
    `(((match (guards guard: (boolean (variable) @font-lock-keyword-face)))
       (:match "otherwise" @font-lock-keyword-face)))
+   
+   :language 'haskell
+   :feature 'type
+   :override t
+   '((type) @font-lock-type-face)
 
-   ;; This needs to be positioned above where we apply
-   ;; font-lock-operator-face to comma
    :language 'haskell
    :override t
    :feature 'signature
@@ -174,21 +177,16 @@ when `haskell-ts-prettify-words' is non-nil.")
      (generator :anchor (_) @haskell-ts--fontify-arg)
      (patterns) @haskell-ts--fontify-arg)
 
-   :language 'haskell
-   :feature 'type
-   :override t
-   '((type) @font-lock-type-face)
-
    :language 'haskell
    :feature 'constructors
    :override t
    '((constructor) @haskell-constructor-face
      (data_constructor
-      (prefix field: (_) @haskell-constructor-face))
-     (newtype_constructor field: (field (name)) @haskell-constructor-face)
-     (declarations (type_synomym (name) @font-lock-type-face))
-     (declarations (data_type name: (name) @font-lock-type-face))
-     (declarations (newtype name: (name) @font-lock-type-face))
+      (prefix field: (_) @haskell-ts--fontify-arg))
+     (type_params (_) @font-lock-variable-name-face)
+     (type_synomym (name) @font-lock-type-face)
+     (data_type name: (name) @font-lock-type-face)
+     (newtype name: (name) @font-lock-type-face)
      (deriving "deriving" @font-lock-keyword-face
                classes: (_) @haskell-constructor-face)
      (deriving_instance "deriving" @font-lock-keyword-face
